@@ -1,8 +1,9 @@
-from __future__ import print_function
-from builtins import range
-import numpy as np
+"""Module to compute the Brillouin zone of a crystal."""
 from collections import defaultdict
 
+import numpy as np
+from scipy.spatial import Voronoi, ConvexHull, Delaunay
+
 
 def get_missing_point(tr, p1, p2):
     """
@@ -13,10 +14,8 @@ def get_missing_point(tr, p1, p2):
     or if all points are among p1 and p2 (e.g. a point repeated twice)
     """
     missing = None
-    for idx, vertex in enumerate(tr):
-        if vertex == p1 or vertex == p2:
-            pass
-        else:
+    for vertex in tr:
+        if vertex not in (p1, p2):
             if missing is not None:
                 raise ValueError("Two missing points found...")
             missing = vertex
@@ -29,10 +28,10 @@ def get_missing_point(tr, p1, p2):
 
 def are_coplanar(v1, v2, v3):
     """
-    v1, v2, v3: 3D vectors. 
+    v1, v2, v3: 3D vectors.
     Return True if they are coplanar, False otherwise
     """
-    return float(abs(np.dot(np.cross(v1, v2), v3))) < 1.e-6
+    return float(abs(np.dot(np.cross(v1, v2), v3))) < 1.0e-6
 
 
 def get_BZ(b1, b2, b3):
@@ -42,7 +41,6 @@ def get_BZ(b1, b2, b3):
         plotting library prefers these - these are not oriented for the
         time being)
     """
-    from scipy.spatial import Voronoi, ConvexHull, Delaunay
     ret_data = {}
 
     supercell_size = 3  # Is this enough?
@@ -55,27 +53,25 @@ def get_BZ(b1, b2, b3):
             for k in range(-supercell_size, supercell_size + 1):
                 if i == 0 and j == 0 and k == 0:
                     central_idx = len(points3d)
-                points3d.append(i * np.array(b1) + j * np.array(b2) +
-                                k * np.array(b3))
+                points3d.append(i * np.array(b1) + j * np.array(b2) + k * np.array(b3))
 
     # Get Voronois
     vor3d = Voronoi(np.array(points3d))
     # Get the vertices of the central" Voronoi( around the origin G=0)
-    central_voronoi_3d = np.array([
-        vor3d.vertices[idx]
-        for idx in vor3d.regions[vor3d.point_region[central_idx]]
-    ])
+    central_voronoi_3d = np.array(
+        [vor3d.vertices[idx] for idx in vor3d.regions[vor3d.point_region[central_idx]]]
+    )
 
     # Get the convex hull of these points (all triangular faces)
     hull = ConvexHull(central_voronoi_3d)
 
     ## REORIENT TRIANGLES
     ## NOTE! TODO: I should do the same for faces
-    ret_data['triangles_vertices'] = hull.points.tolist()
+    ret_data["triangles_vertices"] = hull.points.tolist()
     ## Naive one
     # ret_data['triangles'] = hull.simplices.tolist()
     ## Instead, I orient them all
-    ret_data['triangles'] = []
+    ret_data["triangles"] = []
     for simplex in hull.simplices:
         points = np.array([hull.points[i] for i in simplex])
         center = points.sum(axis=0) / float(len(points))
@@ -84,9 +80,9 @@ def get_BZ(b1, b2, b3):
         normal = np.cross(center - points[1], center - points[0])
         # Normalize, then rescale to a small value
         normal = normal / np.linalg.norm(normal)
-        max_length = np.sqrt((points**2).sum(axis=1).max())
+        max_length = np.sqrt((points ** 2).sum(axis=1).max())
         normal /= max_length
-        normal *= 1.e-4
+        normal *= 1.0e-4
         point_up = center + normal
         point_down = center - normal
         delaunay = Delaunay(hull.points)
@@ -99,16 +95,18 @@ def get_BZ(b1, b2, b3):
             correct_orientation = False
         else:
             inside_outside_string = "inside" if is_up_inside else "outside"
-            print ("WARNING! Both vectors are {}..."\
-                " not changing orientation".format(inside_outside_string))
+            print(
+                "WARNING! Both vectors are {}..."
+                " not changing orientation".format(inside_outside_string)
+            )
             correct_orientation = True
 
         if correct_orientation:
-            ret_data['triangles'].append(simplex.tolist())
+            ret_data["triangles"].append(simplex.tolist())
         else:
-            ret_data['triangles'].append(simplex[::-1].tolist())
+            ret_data["triangles"].append(simplex[::-1].tolist())
 
-    #print hull.area, hull.volume
+    # print hull.area, hull.volume
 
     # Get edge-sharing faces
     # edges has as key a tuple (sorted) with the indices of the two vertices of
@@ -119,13 +117,13 @@ def get_BZ(b1, b2, b3):
         edges[tuple(sorted([simplex[1], simplex[2]]))].append(simplex_idx)
         edges[tuple(sorted([simplex[2], simplex[0]]))].append(simplex_idx)
     # convert to dictionary of lists (from defaultdict of sets)
-    edges = dict(edges)  #{k: v for k, v in edges.iteritems()}
+    edges = dict(edges)
 
     ### Create now the list of faces, merging the triangles that share an
     ### edge and are coplanar. Note: this works only if up to two triangles
     ### must be merged; if three or more, this will not produce the expected
     ### result
-    #print edges
+    # print edges
 
     # Store merge operations to perform
     merge_with = defaultdict(set)
@@ -147,10 +145,8 @@ def get_BZ(b1, b2, b3):
         else:
             # Check if two triangles are coplanar: get the other two
             # vertices that are not on the shared edge
-            otherpoint0 = get_missing_point(hull.simplices[triangles[0]], p1,
-                                            p2)
-            otherpoint1 = get_missing_point(hull.simplices[triangles[1]], p1,
-                                            p2)
+            otherpoint0 = get_missing_point(hull.simplices[triangles[0]], p1, p2)
+            otherpoint1 = get_missing_point(hull.simplices[triangles[1]], p1, p2)
             # The actual vector coordinates
             otherpoint0_p = hull.points[otherpoint0]
             otherpoint1_p = hull.points[otherpoint1]
@@ -158,23 +154,22 @@ def get_BZ(b1, b2, b3):
             p2_p = hull.points[p2]
 
             # Check if they are coplanar
-            if are_coplanar(p2_p - p1_p, otherpoint0_p - p1_p,
-                            otherpoint1_p - p1_p):
+            if are_coplanar(p2_p - p1_p, otherpoint0_p - p1_p, otherpoint1_p - p1_p):
                 merge_with[triangles[0]].add(triangles[1])
                 merge_with[triangles[1]].add(triangles[0])
 
     # PROBLEM TO SOLVE: we have to put together all groups
     ## E.g. we have now:
-    #0: [0, 3]
-    #1: [1, 2, 3]
-    #2: [1, 2]
-    #3: [0, 1, 3]
+    # 0: [0, 3]
+    # 1: [1, 2, 3]
+    # 2: [1, 2]
+    # 3: [0, 1, 3]
     ## We should get instead for all [0,1,2,3]
     # So we have to do a pass to merge them all
     # The algorithm below is probably wrong (actually, it is only
     # probably inefficient)
 
-    #for k, v in merge_with.iteritems():
+    # for k, v in merge_with.items():
     #    print "{}: {}".format(k, list(v))
 
     # Iterate untile convergence - not sure this is correct
@@ -208,17 +203,16 @@ def get_BZ(b1, b2, b3):
 
     for group in groups.values():
         if len(group) == 1:
-            faces.append([
-                hull.points[point_idx] for point_idx in hull.simplices[group[0]]
-            ])
+            faces.append(
+                [hull.points[point_idx] for point_idx in hull.simplices[group[0]]]
+            )
         else:
             # Get all points
             all_points_idx = sorted(
-                set(np.concatenate([hull.simplices[g] for g in group])))
+                set(np.concatenate([hull.simplices[g] for g in group]))
+            )
 
-            all_points_coords = [
-                hull.points[point_idx] for point_idx in all_points_idx
-            ]
+            all_points_coords = [hull.points[point_idx] for point_idx in all_points_idx]
             # Find projection in 2D: I first choose a first vector (between
             # two points v1; I find the orthogonal vector to the plane b;
             # I find a second vector v2 orthogonal to v1 and on the plane
@@ -242,16 +236,14 @@ def get_BZ(b1, b2, b3):
             # 2dhull.vertices contains the segments, but with ids in the
             # smaller subset. We want the indices in the initial set:
             actual_points_idx = [
-                all_points_idx[subset_idx]
-                for subset_idx in hull_face2d.vertices
+                all_points_idx[subset_idx] for subset_idx in hull_face2d.vertices
             ]
             # 4. add to faces list
-            faces.append([
-                hull.points[point_idx].tolist()
-                for point_idx in actual_points_idx
-            ])
+            faces.append(
+                [hull.points[point_idx].tolist() for point_idx in actual_points_idx]
+            )
 
-    ret_data['faces'] = faces
+    ret_data["faces"] = faces
     return ret_data
 
 
@@ -259,12 +251,11 @@ if __name__ == "__main__":
     from pylab import figure, show
     from mpl_toolkits.mplot3d.art3d import Poly3DCollection
 
-    #draw a vector
+    # draw a vector
     from matplotlib.patches import FancyArrowPatch
     from mpl_toolkits.mplot3d import proj3d
 
     class Arrow3D(FancyArrowPatch):
-
         def __init__(self, xs, ys, zs, *args, **kwargs):
             FancyArrowPatch.__init__(self, (0, 0), (0, 0), *args, **kwargs)
             self._verts3d = xs, ys, zs
@@ -276,16 +267,17 @@ if __name__ == "__main__":
             FancyArrowPatch.draw(self, renderer)
 
     ##SC
-    #faces_data = get_BZ(b1 = [1,0,0], b2 = [0,1,0], b3 = [0,0,1])
+    # faces_data = get_BZ(b1 = [1,0,0], b2 = [0,1,0], b3 = [0,0,1])
     ##BCC
-    #faces_data = get_BZ(b1 = [1,1,0], b2 = [1,0,1], b3 = [0,1,1])
+    # faces_data = get_BZ(b1 = [1,1,0], b2 = [1,0,1], b3 = [0,1,1])
     ##FCC
     faces_data = get_BZ(b1=[1, 1, -1], b2=[1, -1, 1], b3=[-1, 1, 1])
 
     import json
+
     print(json.dumps(faces_data))
 
-    faces_coords = faces_data['faces']
+    faces_coords = faces_data["faces"]
 
     faces_count = defaultdict(int)
     for face in faces_coords:
@@ -295,43 +287,57 @@ if __name__ == "__main__":
         print("{} faces: {}".format(num_sides, faces_count[num_sides]))
 
     fig = figure()
-    ax = fig.add_subplot(111, projection='3d')
+    ax = fig.add_subplot(111, projection="3d")
     ax.add_collection3d(
-        Poly3DCollection(faces_coords,
-                         linewidth=1,
-                         alpha=0.9,
-                         edgecolor="k",
-                         facecolor="#ccccff"))
+        Poly3DCollection(
+            faces_coords, linewidth=1, alpha=0.9, edgecolor="k", facecolor="#ccccff"
+        )
+    )
 
-    #draw origin
+    # draw origin
     ax.scatter([0], [0], [0], color="g", s=100)
 
     axes_length = 2
     # Add axes
     ax.add_artist(
-        Arrow3D((0, axes_length), (0, 0), (0, 0),
-                mutation_scale=20,
-                lw=1,
-                arrowstyle="-|>",
-                color="k"))
+        Arrow3D(
+            (0, axes_length),
+            (0, 0),
+            (0, 0),
+            mutation_scale=20,
+            lw=1,
+            arrowstyle="-|>",
+            color="k",
+        )
+    )
     ax.add_artist(
-        Arrow3D((0, 0), (0, axes_length), (0, 0),
-                mutation_scale=20,
-                lw=1,
-                arrowstyle="-|>",
-                color="k"))
+        Arrow3D(
+            (0, 0),
+            (0, axes_length),
+            (0, 0),
+            mutation_scale=20,
+            lw=1,
+            arrowstyle="-|>",
+            color="k",
+        )
+    )
     ax.add_artist(
-        Arrow3D((0, 0), (0, 0), (0, axes_length),
-                mutation_scale=20,
-                lw=1,
-                arrowstyle="-|>",
-                color="k"))
+        Arrow3D(
+            (0, 0),
+            (0, 0),
+            (0, axes_length),
+            mutation_scale=20,
+            lw=1,
+            arrowstyle="-|>",
+            color="k",
+        )
+    )
 
     ## Reset limits
     ax.set_xlim(-1, 1)
     ax.set_ylim(-1, 1)
     ax.set_zlim(-1, 1)
-    ax.axis('off')
+    ax.axis("off")
     ax.view_init(elev=0, azim=60)
 
     show()
